@@ -21,7 +21,6 @@
 #include "clipboard.h"
 #include "simulationthread.h"
 #include "worldgraphics.h"
-#include "worldmodel.moc"
 
 #include "settings.h"
 
@@ -35,9 +34,9 @@
 #include <QApplication>
 #include <QItemSelectionModel>
 #include <QTimer>
-#include <KMenu>
-#include <KIcon>
-#include <KLocale>
+#include <QUndoStack>
+#include <QMenu>
+#include <KLocalizedString>
 
 class CommandEditProperty: public QUndoCommand
 {
@@ -310,7 +309,7 @@ WorldModel::WorldModel(QObject* parent)
     : QAbstractItemModel(parent), _actions(0)
 {
     _selectionModel = new QItemSelectionModel(this, this);
-    _undoStack = new KUndoStack(this);
+    _undoStack = new QUndoStack(this);
     _clipboard = new Clipboard(this);
     _worldFactory = new WorldFactory();
     _world = new StepCore::World();
@@ -741,7 +740,7 @@ QString WorldModel::formatProperty(const StepCore::Object* object,
         return QString("(%1,%2)").arg(v[0], 0, 'g', pr).arg(v[1], 0, 'g', pr).append(units).append(error);
     } else if(property->userTypeId() == qMetaTypeId<StepCore::Vector2dList >() ) {
         // XXX: add error information
-        if(pv) kDebug() << "Unhandled property variance type" << endl;
+//         if(pv) kDebug() << "Unhandled property variance type" << endl;
         StepCore::Vector2dList list =
                 property->readVariant(object).value<StepCore::Vector2dList >();
         QString string;
@@ -811,8 +810,8 @@ QMenu* WorldModel::createContextMenu(const QModelIndex& index)
 {
     //Q_ASSERT(object != NULL);
     Q_ASSERT(index.isValid());
-    KMenu* menu = new KMenu();
-    menu->addTitle(index.data(Qt::DisplayRole).toString());
+    QMenu* menu = new QMenu();
+    menu->addSection(index.data(Qt::DisplayRole).toString());
     ItemMenuHandler* handler = _worldFactory->newItemMenuHandler(object(index), this, menu);
     handler->populateMenu(menu, _actions);
     return menu;
